@@ -1,7 +1,7 @@
 /*
                                   NETWIB
                              Network library
-                Copyright(c) 1999-2005 Laurent Constantin
+                Copyright(c) 1999-2006 Laurent Constantin
                                   -----
 
   Main server    : http://www.laurentconstantin.com/
@@ -770,6 +770,184 @@ netwib_err netwib_buf_cmp(netwib_constbuf *pbuf1,
   return(NETWIB_ERR_OK);
 }
 
+/*-------------------------------------------------------------*/
+netwib_err netwib_buf_casecmp(netwib_constbuf *pbuf1,
+                              netwib_constbuf *pbuf2,
+                              netwib_cmp *pcmp)
+{
+  netwib_uint32 data1size, data2size, commonsize;
+  netwib_cmp cmp=NETWIB_CMP_LT;
+  int reti;
+
+  /* parameter verification */
+  if (pbuf1 != NULL) {
+    if (pbuf1->totalptr == NETWIB_PRIV_BUF_PTR_CLOSED) {
+      return(NETWIB_ERR_LOOBJUSECLOSED);
+    }
+#if NETWIB_DEBUG_LEAK==1
+    netwib_er(netwib_debug_leak_valid_buf(pbuf1->totalptr,
+                                          netwib__priv_buf_get_leakid(pbuf1)));
+#endif
+  }
+  if (pbuf2 != NULL) {
+    if (pbuf2->totalptr == NETWIB_PRIV_BUF_PTR_CLOSED) {
+      return(NETWIB_ERR_LOOBJUSECLOSED);
+    }
+#if NETWIB_DEBUG_LEAK==1
+    netwib_er(netwib_debug_leak_valid_buf(pbuf2->totalptr,
+                                          netwib__priv_buf_get_leakid(pbuf2)));
+#endif
+  }
+
+  data1size = netwib__buf_ref_data_sizenull(pbuf1);
+  data2size = netwib__buf_ref_data_sizenull(pbuf2);
+  if (data1size == 0 && data2size == 0) {
+    cmp = NETWIB_CMP_EQ;
+  } else if (data1size == 0) {
+    cmp = NETWIB_CMP_LT;
+  } else if (data2size == 0) {
+    cmp = NETWIB_CMP_GT;
+  } else {
+    commonsize = (data1size<data2size)?data1size:data2size;
+    reti = netwib_c_memcasecmp(pbuf1->totalptr+pbuf1->beginoffset,
+                               pbuf2->totalptr+pbuf2->beginoffset, commonsize);
+    if (reti == 0) {
+      if (data1size == data2size) {
+        cmp = NETWIB_CMP_EQ;
+      } else {
+        cmp = (data1size<data2size)?NETWIB_CMP_LT:NETWIB_CMP_GT;
+      }
+    } else if (reti < 0) {
+      cmp = NETWIB_CMP_LT;
+    } else {
+      cmp = NETWIB_CMP_GT;
+    }
+  }
+
+  if (pcmp != NULL) *pcmp = cmp;
+  return(NETWIB_ERR_OK);
+}
+
+/*-------------------------------------------------------------*/
+netwib_err netwib_buf_cmp_str(netwib_constbuf *pbuf1,
+                              netwib_conststring string2,
+                              netwib_cmp *pcmp)
+{
+  netwib_conststring ps;
+  netwib_data data;
+  netwib_uint32 datasize;
+  netwib_char c1, c2=0;
+  netwib_cmp cmp=NETWIB_CMP_LT;
+
+  /* parameter verification */
+  if (pbuf1 != NULL) {
+    if (pbuf1->totalptr == NETWIB_PRIV_BUF_PTR_CLOSED) {
+      return(NETWIB_ERR_LOOBJUSECLOSED);
+    }
+#if NETWIB_DEBUG_LEAK==1
+    netwib_er(netwib_debug_leak_valid_buf(pbuf1->totalptr,
+                                          netwib__priv_buf_get_leakid(pbuf1)));
+#endif
+  }
+
+  datasize = netwib__buf_ref_data_sizenull(pbuf1);
+  data = datasize?netwib__buf_ref_data_ptr(pbuf1):NULL;
+  ps = string2;
+
+  while (NETWIB_TRUE) {
+    if (string2 == NULL) {
+      c2 = '\0';
+    } else {
+      c2 = *ps++;
+    }
+    if (c2 == '\0') {
+      if (datasize == 0) {
+        cmp = NETWIB_CMP_EQ;
+      } else {
+        cmp = NETWIB_CMP_GT;
+      }
+      break;
+    }
+    if (datasize == 0) {
+      cmp = NETWIB_CMP_LT;
+      break;
+    }
+    c1 = *data++;
+    datasize--;
+    if (c1 > c2) {
+      cmp = NETWIB_CMP_GT;
+      break;
+    } else if (c1 < c2) {
+      cmp = NETWIB_CMP_LT;
+      break;
+    }
+  }
+
+  if (pcmp != NULL) *pcmp = cmp;
+  return(NETWIB_ERR_OK);
+}
+
+/*-------------------------------------------------------------*/
+netwib_err netwib_buf_casecmp_str(netwib_constbuf *pbuf1,
+                                  netwib_conststring string2,
+                                  netwib_cmp *pcmp)
+{
+  netwib_conststring ps;
+  netwib_data data;
+  netwib_uint32 datasize;
+  netwib_char c1, c2=0;
+  netwib_cmp cmp=NETWIB_CMP_LT;
+
+  /* parameter verification */
+  if (pbuf1 != NULL) {
+    if (pbuf1->totalptr == NETWIB_PRIV_BUF_PTR_CLOSED) {
+      return(NETWIB_ERR_LOOBJUSECLOSED);
+    }
+#if NETWIB_DEBUG_LEAK==1
+    netwib_er(netwib_debug_leak_valid_buf(pbuf1->totalptr,
+                                          netwib__priv_buf_get_leakid(pbuf1)));
+#endif
+  }
+
+  datasize = netwib__buf_ref_data_sizenull(pbuf1);
+  data = datasize?netwib__buf_ref_data_ptr(pbuf1):NULL;
+  ps = string2;
+
+  while (NETWIB_TRUE) {
+    if (string2 == NULL) {
+      c2 = '\0';
+    } else {
+      c2 = *ps++;
+    }
+    if (c2 == '\0') {
+      if (datasize == 0) {
+        cmp = NETWIB_CMP_EQ;
+      } else {
+        cmp = NETWIB_CMP_GT;
+      }
+      break;
+    }
+    if (datasize == 0) {
+      cmp = NETWIB_CMP_LT;
+      break;
+    }
+    c1 = *data++;
+    datasize--;
+    netwib_c2_lower(c2);
+    netwib_c2_lower(c1);
+    if (c1 > c2) {
+      cmp = NETWIB_CMP_GT;
+      break;
+    } else if (c1 < c2) {
+      cmp = NETWIB_CMP_LT;
+      break;
+    }
+  }
+
+  if (pcmp != NULL) *pcmp = cmp;
+  return(NETWIB_ERR_OK);
+}
+
 /*-------------------------------------------------------------*/
 netwib_err netwib_buf_close(netwib_buf *pbuf)
 {
