@@ -1031,8 +1031,8 @@ netwib_err netwib_debug_memcorrupt_free_check(netwib_constptr trueptr,
                                               netwib_uint32 trueallocsize)
 {
   /* there is no check in this case */
+  trueptr = trueptr; /* for compiler warning */
+  trueallocsize = trueallocsize; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  trueptr = trueptr;
-  trueallocsize = trueallocsize;
 }
 #endif
