@@ -21,6 +21,9 @@
 #if NETWIBDEF_HAVEINCL_ASM_PAGE==1
  #include <asm/page.h>
 #endif
+#if NETWIBDEF_HAVEINCL_MACH_MACHINE_VMPARAM==1
+ #include <mach/machine/vm_param.h>
+#endif
 
 /*-------------------------------------------------------------*/
 /* If PAGESIZE is not defined on the system (which might be ok
