@@ -452,11 +452,11 @@ static netwib_err netwib_priv_io_spoof_ip_wait(netwib_io *pio,
 {
   *pevent = NETWIB_TRUE;
 
+  pio = pio; /* for compiler warning */
+  way = way; /* for compiler warning */
+  pabstime = pabstime; /* for compiler warning */
+  pevent = pevent; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pio = pio;
-  way = way;
-  pabstime = pabstime;
-  pevent = pevent;
 }
 
 /*-------------------------------------------------------------*/
@@ -475,10 +475,10 @@ static netwib_err netwib_priv_io_spoof_ip_ctl_get(netwib_io *pio,
       return(NETWIB_ERR_PLEASETRYNEXT);
   }
 
+  pio = pio; /* for compiler warning */
+  way = way; /* for compiler warning */
+  p = p; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
-  pio = pio;
-  way = way;
-  p = p;
 }
 
 /*-------------------------------------------------------------*/
