@@ -167,8 +167,9 @@ static netwib_err netwib_priv_confclean_arpcache_setdev(netwib_priv_confwork *pc
       if (ret == NETWIB_ERR_DATAEND) ret = NETWIB_ERR_OK;
       break;
     }
-    netwib_eg(netwib_priv_ip_cmp_maskprefix(&pci->ip, &pca->ip, &pci->mask,
-                                            pci->prefix, &cmp));
+    netwib_eg(netwib_priv_ip_net_cmp_ipmaskprefix(&pci->ip, &pca->ip,
+                                                  &pci->mask,
+                                                  pci->prefix, &cmp));
     if (cmp == NETWIB_CMP_EQ) {
       netwib_eg(netwib_buf_append_buf(&pci->device, &pca->device));
     }
@@ -250,12 +251,14 @@ static netwib_err netwib_priv_confclean_routes_setdevsrc(netwib_priv_confwork *p
     }
 
     /* if gw or dst is on the LAN */
-    netwib_eg(netwib_priv_ip_cmp_maskprefix(&pci->ip, &pcr->dst, &pci->mask,
-                                            pci->prefix, &cmp));
+    netwib_eg(netwib_priv_ip_net_cmp_ipmaskprefix(&pci->ip, &pcr->dst,
+                                                  &pci->mask,
+                                                  pci->prefix, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       if (pcr->gwset) {
-        netwib_eg(netwib_priv_ip_cmp_maskprefix(&pci->ip, &pcr->gw, &pci->mask,
-                                                pci->prefix, &cmp));
+        netwib_eg(netwib_priv_ip_net_cmp_ipmaskprefix(&pci->ip, &pcr->gw,
+                                                      &pci->mask,
+                                                      pci->prefix, &cmp));
       }
     }
     if (cmp == NETWIB_CMP_EQ) {
@@ -386,8 +389,8 @@ static netwib_err netwib_priv_confclean_devip_addsys(netwib_priv_confwork *pcw,
     addnet = NETWIB_FALSE;
   }
   if (addnet) {
-    netwib_er(netwib_priv_ip_init_maskprefix(&pci->ip, &pci->mask,
-                                             pci->prefix, &net));
+    netwib_er(netwib_priv_ip_net_init_ipmaskprefix(&pci->ip, &pci->mask,
+                                                   pci->prefix, &net));
     netwib_er(netwib_priv_confwork_routes_init(&pcr));
     netwib_er(netwib_buf_append_buf(&pcd->device, &pcr->device));
     pcr->dst = net;
