@@ -1,6 +1,8 @@
 /* This file is part of Netwib.
 */
 
+/* IMPORTANT : NOT YET IMPLEMENTED */
+
 /*-------------------------------------------------------------*/
 static netwib_err netwib_priv_confwork_obtain_sys(netwib_priv_confwork *pcw)
 {
@@ -26,6 +28,6 @@ static netwib_err netwib_priv_confwork_obtain_sys(netwib_priv_confwork *pcw)
 /*-------------------------------------------------------------*/
 netwib_err netwib_priv_confwork_obtain_arpcache(netwib_priv_confwork *pcw)
 {
+  pcw = pcw; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pcw = pcw;
 }
