@@ -1,19 +1,16 @@
 /* This file is part of Netwib.
 */
 
-/*-------------------------------------------------------------*/
-static netwib_err netwib_priv_conf_loopback(netwib_priv_confwork *pcw)
-{
-  netwib_priv_confwork_devices *pcd;
-
-  netwib_er(netwib_priv_confwork_devices_init(&pcd));
-  netwib_er(netwib_buf_append_text("lo0", &pcd->device));
-  pcd->hwtype = NETWIB_DEVICE_HWTYPE_LOOPBACK;
-  netwib_er(netwib_priv_confwork_devices_add(pcw, pcd));
-  return(NETWIB_ERR_OK);
-}
+/* IPv6 not yet supported because I never had access to a computer with IPv6 */
 
 /*-------------------------------------------------------------*/
+/*
+HP-UX B.11.23, B.11.11
+/usr/bin/netstat -in
+Name      Mtu  Network         Address         Ipkts   Ierrs Opkts   Oerrs Coll
+lan0      1500 5.1.1.0         5.1.1.176       430317  0     5109438 0     0
+lo0       4136 127.0.0.0       127.0.0.1       1107962 0     1107963 0     0
+*/
 static netwib_err netwib_priv_conf_netstatin(netwib_priv_confwork *pcw)
 {
   netwib_io *piofile, *pioline;
@@ -63,7 +60,7 @@ static netwib_err netwib_priv_conf_netstatin(netwib_priv_confwork *pcw)
     } else if (ret != NETWIB_ERR_OK) {
       break;
     }
-    ret = netwib_priv_ip_init_bufnet(&bufnet, &net);
+    ret = netwib_priv_ip_net_init_buf(&bufnet, &net);
     if (ret == NETWIB_ERR_NOTCONVERTED) {
       ret = NETWIB_ERR_OK;
       goto netwib_trynextentry;
@@ -79,6 +76,11 @@ static netwib_err netwib_priv_conf_netstatin(netwib_priv_confwork *pcw)
     } else if (ret != NETWIB_ERR_OK) {
       break;
     }
+    /* detect loopback */
+    if (pci->ip.iptype == NETWIB_IPTYPE_IP4 &&
+        pci->ip.ipvalue.ip4 == 0x7F000001u) {
+      pcd->hwtype = NETWIB_DEVICE_HWTYPE_LOOPBACK;
+    }
     /* set 2nd device */
     netwib_eg(netwib_buf_append_buf(&pcd->device, &pci->device));
     /* add it */
@@ -139,6 +141,12 @@ static netwib_err netwib_priv_conf_lanscanmai2(netwib_buf *pbuf,
 }
 
 /*-------------------------------------------------------------*/
+/*
+HP-UX B.11.23, B.11.11
+/usr/sbin/lanscan -mai
+0x0011855FAAA2 lan0 snap0     ETHER
+0x0011855FAAA3 lan1 snap1     ETHER
+*/
 static netwib_err netwib_priv_conf_lanscanmai(netwib_priv_confwork *pcw)
 {
   netwib_io *piofile, *pioline;
@@ -221,6 +229,12 @@ static netwib_err netwib_priv_conf_lanscanmai(netwib_priv_confwork *pcw)
 }
 
 /*-------------------------------------------------------------*/
+/*
+HP-UX B.11.23, B.11.11
+/usr/sbin/lanscan -ai
+0x0011855FAAA2 lan0 snap0
+0x0011855FAAA3 lan1 snap0
+*/
 static netwib_err netwib_priv_conf_lanscanai(netwib_priv_confwork *pcw)
 {
   netwib_io *piofile, *pioline;
@@ -296,6 +310,12 @@ static netwib_err netwib_priv_conf_lanscanai(netwib_priv_confwork *pcw)
 }
 
 /*-------------------------------------------------------------*/
+/*
+HP-UX B.11.23, B.11.11
+/usr/sbin/arp -an
+ (1.1.1.129) at 0:d:88:11:aa:aa ether
+ (1.1.1.253) at 0:60:6d:21:aa:aa ether
+*/
 static netwib_err netwib_priv_conf_arpan(netwib_priv_confwork *pcw)
 {
   netwib_io *piofile, *pioline;
@@ -360,29 +380,17 @@ static netwib_err netwib_priv_conf_arpan(netwib_priv_confwork *pcw)
 }
 
 /*-------------------------------------------------------------*/
-static netwib_err netwib_priv_conf_decodedst(netwib_constbuf *pbufdst,
-                                             netwib_ip *pdst)
-{
-  netwib_buf buf;
-  netwib_cmp cmp;
-
-  /* IP4 : 1.2.3.4 or default
-     IP6 : ???
-  */
-
-  netwib_er(netwib_buf_init_ext_text("default", &buf));
-  netwib_er(netwib_buf_cmp(pbufdst, &buf, &cmp));
-  if (cmp == NETWIB_CMP_EQ) {
-    netwib_er(netwib_ip_init_ip4_fields(0,0,0,0, pdst));
-    return(NETWIB_ERR_OK);
-  }
-
-  netwib_er(netwib_priv_ip_init_bufnet(pbufdst, pdst));
-
-  return(NETWIB_ERR_OK);
-}
-
-/*-------------------------------------------------------------*/
+/*
+HP-UX B.11.23, B.11.11
+/usr/bin/netstat -rvn
+Routing tables
+Dest/Netmask                    Gateway        Flags   Refs Interface  Pmtu
+127.0.0.1/255.255.255.255       127.0.0.1      UH        0  lo0        4136
+15.1.1.192/255.255.255.255      15.1.1.192     UH        0  lan0       4136
+15.1.1.0/255.255.255.0          15.1.1.192     U         2  lan0       1500
+127.0.0.0/255.0.0.0             127.0.0.1      U         0  lo0           0
+default/0.0.0.0                 15.1.1.129     UG        0  lan0          0
+*/
 static netwib_err netwib_priv_conf_netstatrvn(netwib_priv_confwork *pcw)
 {
   netwib_io *piofile, *pioline;
@@ -440,7 +448,8 @@ static netwib_err netwib_priv_conf_netstatrvn(netwib_priv_confwork *pcw)
       pcr->srcset = NETWIB_TRUE;
     }
     /* convert bufdst */
-    ret = netwib_priv_conf_decodedst(&bufdst, &pcr->dst);
+    ret = netwib_priv_ip_net_init_bufdefault(NETWIB_IPTYPE_IP4, &bufdst,
+                                             &pcr->dst);
     if (ret == NETWIB_ERR_NOTCONVERTED) {
       ret = NETWIB_ERR_OK;
       goto trynextentry;
@@ -478,6 +487,22 @@ static netwib_err netwib_priv_conf_netstatrvn(netwib_priv_confwork *pcw)
 }
 
 /*-------------------------------------------------------------*/
+/*
+Note: It's a guess. I don't have access anymore to this system :(
+      netwib_priv_conf_netstatrvn() and netstatrvnskip() functions
+      should be mixed to support both formats.
+/usr/bin/netstat -rvn
+Routing tables
+Dest/Netmask          Gateway        Flags   Refs ?? Interface  Pmtu
+127.0.0.1/255.255.255.255
+                      127.0.0.1      UH        0  ?? lo0        4136
+15.1.1.192/255.255.255.255
+                      15.1.1.192     UH        0  ?? lan0       4136
+15.1.1.0/255.255.255.0
+                      15.1.1.192     U         2  ?? lan0       1500
+127.0.0.0/255.0.0.0   127.0.0.1      U         0  ?? lo0           0
+default/0.0.0.0       15.1.1.129     UG        0  ?? lan0          0
+*/
 static netwib_err netwib_priv_conf_netstatrvnskip(netwib_priv_confwork *pcw)
 {
   netwib_io *piofile, *pioline;
@@ -545,7 +570,8 @@ static netwib_err netwib_priv_conf_netstatrvnskip(netwib_priv_confwork *pcw)
       pcr->srcset = NETWIB_TRUE;
     }
     /* convert bufdst */
-    ret = netwib_priv_conf_decodedst(&bufdst, &pcr->dst);
+    ret = netwib_priv_ip_net_init_bufdefault(NETWIB_IPTYPE_IP4, &bufdst,
+                                             &pcr->dst);
     if (ret == NETWIB_ERR_NOTCONVERTED) {
       ret = NETWIB_ERR_OK;
       goto trynextentry;
@@ -581,9 +607,6 @@ static netwib_err netwib_priv_confwork_obtain_sys(netwib_priv_confwork *pcw)
 {
   netwib_err ret;
 
-  netwib_er(netwib_priv_conf_loopback(pcw));
-  netwib_er(netwib_priv_confwork_debug(pcw, "After loopback"));
-
   ret = netwib_priv_conf_netstatin(pcw);
   if (ret != NETWIB_ERR_OK) {
     if (ret != NETWIB_ERR_LONOTSUPPORTED) {
