@@ -32,6 +32,15 @@ static netwib_err netwib_priv_conf_ip6_init_bufhexa(netwib_buf *pbuf,
 }
 
 /*-------------------------------------------------------------*/
+/*
+Linux 2.4.22
+/proc/net/if_inet6
+fec00000000000110000000000000001 04 40 40 80     eth1
+fec00000000000100000000000000001 03 40 40 80     eth0
+fe80000000000000024095fffe46aaaa 03 40 20 80     eth0
+00000000000000000000000000000001 01 80 10 80       lo
+fe8000000000000002104bfffe44aaaa 04 40 20 80     eth1
+*/
 static netwib_err netwib_priv_conf_procnetifinet6(netwib_priv_confwork *pcw)
 {
   netwib_io *piofile, *pioline;
@@ -99,6 +108,13 @@ static netwib_err netwib_priv_conf_procnetifinet6(netwib_priv_confwork *pcw)
 }
 
 /*-------------------------------------------------------------*/
+/*
+Linux 2.4.22
+/proc/net/arp
+IP address       HW type     Flags       HW address            Mask     Device
+192.168.1.3      0x1         0x0         00:00:00:00:00:00     *        eth0
+192.168.1.2      0x1         0x6         01:01:01:01:01:01     *        eth0
+*/
 static netwib_err netwib_priv_conf_procnetarp(netwib_priv_confwork *pcw)
 {
   netwib_io *piofile, *pioline;
@@ -223,6 +239,12 @@ static netwib_err netwib_priv_conf_procnetrarp(netwib_priv_confwork *pcw)
 }
 
 /*-------------------------------------------------------------*/
+/*
+Linux 2.4.22
+/bin/ip neigh show
+192.168.1.3 dev eth0  nud failed
+192.168.1.2 dev eth0 lladdr 01:01:01:01:01:01 nud permanent
+*/
 static netwib_err netwib_priv_conf_binip(netwib_priv_confwork *pcw)
 {
   netwib_io *piofile, *pioline;
@@ -298,6 +320,16 @@ static netwib_err netwib_priv_conf_binip(netwib_priv_confwork *pcw)
 }
 
 /*-------------------------------------------------------------*/
+/*
+Linux 2.4.22
+/proc/net/route
+Iface   Destination     Gateway         Flags   RefCnt  Use     Metric  Mask            MTU     Window  IRTT
+eth0    00AAAAC0        00000000        0001    0       0       0       00FFFFFF        0       0       0
+eth1    000AAAC0        00000000        0001    0       0       0       00FFFFFF        0       0       0
+eth0    000AAAC0        00000000        0001    0       0       0       00FFFFFF        0       0       0
+eth0    00000051        00000000        0001    0       0       0       000000FF        0       0       0
+eth0    00000000        FE0AAAC0        0003    0       0       0       00000000        0       0       0
+*/
 static netwib_err netwib_priv_conf_procnetroute(netwib_priv_confwork *pcw)
 {
   netwib_io *piofile, *pioline;
@@ -368,6 +400,24 @@ static netwib_err netwib_priv_conf_procnetroute(netwib_priv_confwork *pcw)
 }
 
 /*-------------------------------------------------------------*/
+/*
+Linux 2.4.22
+/proc/net/ipv6_route
+00000000000000000000000000000001 80 00000000000000000000000000000000 00 00000000000000000000000000000000 00000000 00000000 00000000 00200001       lo
+fe8000000000000002104bfffeAAAA97 80 00000000000000000000000000000000 00 00000000000000000000000000000000 00000000 00000000 00000000 00200001       lo
+fe80000000000000024095fffeAAAAcb 80 00000000000000000000000000000000 00 00000000000000000000000000000000 00000000 00000000 00000000 00200001       lo
+fe800000000000000000000000000000 40 00000000000000000000000000000000 00 00000000000000000000000000000000 00000100 00000000 00000000 00040001     eth0
+fe800000000000000000000000000000 40 00000000000000000000000000000000 00 00000000000000000000000000000000 00000100 00000000 00000000 00040001     eth1
+fec00000000000100000000000000001 80 00000000000000000000000000000000 00 00000000000000000000000000000000 00000000 00000000 00000000 00200001       lo
+fec00000000000100000000000000000 40 00000000000000000000000000000000 00 00000000000000000000000000000000 00000100 00000000 00000000 00040001     eth0
+fec00000000000110000000000000001 80 00000000000000000000000000000000 00 00000000000000000000000000000000 00000000 00000000 00000000 00200001       lo
+fec00000000000110000000000000000 40 00000000000000000000000000000000 00 00000000000000000000000000000000 00000100 00000000 00000000 00040001     eth1
+ff000000000000000000000000000000 08 00000000000000000000000000000000 00 00000000000000000000000000000000 00000100 00000000 00000000 00040001     eth0
+ff000000000000000000000000000000 08 00000000000000000000000000000000 00 00000000000000000000000000000000 00000100 00000000 00000000 00040001     eth1
+00000000000000000000000000000000 00 00000000000000000000000000000000 00 00000000000000000000000000000000 00000100 00000000 00000000 00070001     eth0
+00000000000000000000000000000000 00 00000000000000000000000000000000 00 00000000000000000000000000000000 00000100 00000000 00000000 00070001     eth1
+00000000000000000000000000000000 00 00000000000000000000000000000000 00 00000000000000000000000000000000 ffffffff 00000001 00000001 00200200       lo
+*/
 static netwib_err netwib_priv_conf_procnetipv6route(netwib_priv_confwork *pcw)
 {
   netwib_io *piofile, *pioline;
