@@ -138,8 +138,7 @@ static netwib_err netwib_priv_conf_devices_sysctl(netwib_priv_confwork *pcw)
                                                   &pci->prefix);
         } else if (i == RTAX_BRD) {
           if (ispointtopoint) {
-            ret = netwib_priv_sa_ip_init_sai(psa, iptype,
-                                             &pci->pointtopointip);
+            ret = netwib_priv_sa_ip_init_sai(psa, iptype, &pci->pointtopointip);
           }
         }
         if (ret == NETWIB_ERR_PAINVALIDTYPE ||
