@@ -8,9 +8,18 @@
 #define netwib_gethostbyaddr gethostbyaddr
 
 /*-------------------------------------------------------------*/
-static netwib_err netwib_priv_ip_bad(netwib_conststring str)
+static netwib_err netwib_priv_ip4_bad(netwib_conststring str)
 {
-  netwib_er(netwib_priv_errmsg_text("this is not an IP address: "));
+  netwib_er(netwib_priv_errmsg_text("this is not an IPv4 address: "));
+  netwib_er(netwib_priv_errmsg_append_text(str));
+
+  return(NETWIB_ERR_OK);
+}
+
+/*-------------------------------------------------------------*/
+static netwib_err netwib_priv_ip6_bad(netwib_conststring str)
+{
+  netwib_er(netwib_priv_errmsg_text("this is not an IPv6 address: "));
   netwib_er(netwib_priv_errmsg_append_text(str));
 
   return(NETWIB_ERR_OK);
@@ -84,9 +93,13 @@ netwib_err netwib_priv_ip_ip6_init_ip4(netwib_ip4 ip4,
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_priv_ip_init_sip4(netwib_conststring str,
-                                    netwib_bool acceptnet,
-                                    netwib_ip *pip)
+/* if acceptnet is set, also accept "1.2.3" for "1.2.3.0"
+   and "127" for "127.0.0.0". In this case, pmask|pprefix is guessed */
+static netwib_err netwib_priv_ip_netmaskprefix_init_sip4(netwib_conststring str,
+                                                         netwib_bool acceptnet,
+                                                         netwib_ip *pnet,
+                                                         netwib_ip *pmask,
+                                                         netwib_uint32 *pprefix)
 {
   netwib_conststring pc;
   netwib_char c;
@@ -107,16 +120,23 @@ netwib_err netwib_priv_ip_init_sip4(netwib_conststring str,
   while (NETWIB_TRUE) {
     c = *pc;
     if (c == '\0' || c == ' ' || c == '\t' ) {
+      if (numdigitfound == 0) {
+        netwib_er(netwib_priv_ip4_bad(str));
+        return(NETWIB_ERR_NOTCONVERTED);
+      }
+      ip4 = (ip4 << 8) | fieldvalue;
+      numfieldsfound++;
+      numdigitfound = 0;
       break;
     }
     pc++;
     if (c == '.') {
       if (numdigitfound == 0) {
-        netwib_er(netwib_priv_ip_bad(str));
+        netwib_er(netwib_priv_ip4_bad(str));
         return(NETWIB_ERR_NOTCONVERTED);
       }
       if (numfieldsfound == 3) {
-        netwib_er(netwib_priv_ip_bad(str));
+        netwib_er(netwib_priv_ip4_bad(str));
         return(NETWIB_ERR_NOTCONVERTED);
       }
       ip4 = (ip4 << 8) | fieldvalue;
@@ -125,42 +145,37 @@ netwib_err netwib_priv_ip_init_sip4(netwib_conststring str,
       numdigitfound = 0;
     } else if (netwib_c2_isdigit(c)) {
       if (numdigitfound == 3) {
-        netwib_er(netwib_priv_ip_bad(str));
+        netwib_er(netwib_priv_ip4_bad(str));
         return(NETWIB_ERR_NOTCONVERTED);
       }
       fieldvalue = fieldvalue*10 + netwib_c2_cto9(c);
       if (fieldvalue > 255) {
-        netwib_er(netwib_priv_ip_bad(str));
+        netwib_er(netwib_priv_ip4_bad(str));
         return(NETWIB_ERR_NOTCONVERTED);
       }
       numdigitfound++;
     } else {
-      netwib_er(netwib_priv_ip_bad(str));
+      netwib_er(netwib_priv_ip4_bad(str));
       return(NETWIB_ERR_NOTCONVERTED);
     }
   }
 
   /* check values */
-  if (numdigitfound == 0) {
-    netwib_er(netwib_priv_ip_bad(str));
-    return(NETWIB_ERR_NOTCONVERTED);
-  }
-  ip4 = (ip4 << 8) | fieldvalue;
   if (acceptnet) {
     switch(numfieldsfound) {
-    case 0 :
+    case 1 :
       ip4 = ip4 << 24;
       break;
-    case 1 :
+    case 2 :
       ip4 = ip4 << 16;
       break;
-    case 2 :
+    case 3 :
       ip4 = ip4 << 8;
       break;
     }
   } else {
-    if (numfieldsfound != 3) {
-      netwib_er(netwib_priv_ip_bad(str));
+    if (numfieldsfound != 4) {
+      netwib_er(netwib_priv_ip4_bad(str));
       return(NETWIB_ERR_NOTCONVERTED);
     }
   }
@@ -170,17 +185,28 @@ netwib_err netwib_priv_ip_init_sip4(netwib_conststring str,
     pc++;
   }
   if (*pc != '\0') {
-    netwib_er(netwib_priv_ip_bad(str));
+    netwib_er(netwib_priv_ip4_bad(str));
     return(NETWIB_ERR_NOTCONVERTED);
   }
 
-  if (pip != NULL) {
-    pip->iptype = NETWIB_IPTYPE_IP4;
-    pip->ipvalue.ip4 = ip4;
+  if (pnet != NULL) {
+    pnet->iptype = NETWIB_IPTYPE_IP4;
+    pnet->ipvalue.ip4 = ip4;
   }
+  netwib_er(netwib_priv_ip_maskprefix_init_prefix(NETWIB_IPTYPE_IP4,
+                                                  8*numfieldsfound,
+                                                  pmask,pprefix));
   return(NETWIB_ERR_OK);
 }
 
+/*-------------------------------------------------------------*/
+netwib_err netwib_priv_ip_init_sip4(netwib_conststring str,
+                                    netwib_ip *pip)
+{
+  return(netwib_priv_ip_netmaskprefix_init_sip4(str, NETWIB_FALSE, pip,
+                                                NULL, NULL));
+}
+
 /*-------------------------------------------------------------*/
 netwib_err netwib_priv_ip_init_sip6(netwib_conststring str,
                                     netwib_ip *pip)
@@ -209,12 +235,12 @@ netwib_err netwib_priv_ip_init_sip6(netwib_conststring str,
     if (c == '\0' || c == ' ' || c == '\t' ) {
       if (extendindex == (netwib_uint32)-1) {
         if (numdigitfound == 0 || numfieldsfound != 7) {
-          netwib_er(netwib_priv_ip_bad(str));
+          netwib_er(netwib_priv_ip6_bad(str));
           return(NETWIB_ERR_NOTCONVERTED);
         }
       } else {
         if (numfieldsfound > 7) {
-          netwib_er(netwib_priv_ip_bad(str));
+          netwib_er(netwib_priv_ip6_bad(str));
           return(NETWIB_ERR_NOTCONVERTED);
         }
       }
@@ -226,7 +252,7 @@ netwib_err netwib_priv_ip_init_sip6(netwib_conststring str,
       if (numdigitfound == 0) {
         if (numfieldsfound != 0) {
           if (extendindex != (netwib_uint32)-1) {
-            netwib_er(netwib_priv_ip_bad(str));
+            netwib_er(netwib_priv_ip6_bad(str));
             return(NETWIB_ERR_NOTCONVERTED);
           }
           /* this is index for "::" */
@@ -234,7 +260,7 @@ netwib_err netwib_priv_ip_init_sip6(netwib_conststring str,
         }
       }
       if (numfieldsfound == 7) {
-        netwib_er(netwib_priv_ip_bad(str));
+        netwib_er(netwib_priv_ip6_bad(str));
         return(NETWIB_ERR_NOTCONVERTED);
       }
       array[numfieldsfound] = (netwib_uint16)fieldvalue;
@@ -246,23 +272,23 @@ netwib_err netwib_priv_ip_init_sip6(netwib_conststring str,
       netwib_ip ipfor4;
       /* search an IP4 from last start */
       if (numfieldsfound == 0 || numfieldsfound > 6) {
-        netwib_er(netwib_priv_ip_bad(str));
+        netwib_er(netwib_priv_ip6_bad(str));
         return(NETWIB_ERR_NOTCONVERTED);
       }
-      netwib_er(netwib_priv_ip_init_sip4(pclaststart, NETWIB_FALSE, &ipfor4));
+      netwib_er(netwib_priv_ip_init_sip4(pclaststart, &ipfor4));
       array[numfieldsfound++] = (netwib_uint16)(ipfor4.ipvalue.ip4 >> 16);
       array[numfieldsfound++] = (netwib_uint16)(ipfor4.ipvalue.ip4 & 0xFFFF);
       needtocheendspaces = NETWIB_FALSE;
       break;
     } else if (netwib_c2_isxdigit(c)) {
       if (numdigitfound == 4) {
-        netwib_er(netwib_priv_ip_bad(str));
+        netwib_er(netwib_priv_ip6_bad(str));
         return(NETWIB_ERR_NOTCONVERTED);
       }
       fieldvalue = (fieldvalue<<4) + netwib_c2_cto16(c);
       numdigitfound++;
     } else {
-      netwib_er(netwib_priv_ip_bad(str));
+      netwib_er(netwib_priv_ip6_bad(str));
       return(NETWIB_ERR_NOTCONVERTED);
     }
   }
@@ -283,7 +309,7 @@ netwib_err netwib_priv_ip_init_sip6(netwib_conststring str,
       pc++;
     }
     if (*pc != '\0') {
-      netwib_er(netwib_priv_ip_bad(str));
+      netwib_er(netwib_priv_ip6_bad(str));
       return(NETWIB_ERR_NOTCONVERTED);
     }
   }
@@ -388,8 +414,7 @@ netwib_err netwib_priv_ip_init_hn6(netwib_conststring hn,
     if (reti == 0) {
       pcur = pres;
       while(pcur != NULL) {
-        ret = netwib_priv_sa_ip_init_sa((netwib_priv_sockaddr_unalign *)pcur->ai_addr,
-                                        pip);
+        ret = netwib_priv_sa_ip_init_sa((netwib_priv_sockaddr_unalign *)pcur->ai_addr, pip);
         if (ret == NETWIB_ERR_OK) {
           freeaddrinfo(pres);
           return(NETWIB_ERR_OK);
@@ -428,24 +453,6 @@ netwib_err netwib_priv_ip_init_hn6(netwib_conststring hn,
   return(NETWIB_ERR_OK);
 }
 
-/*-------------------------------------------------------------*/
-netwib_err netwib_priv_ip_init_bufnet(netwib_constbuf *pbuf,
-                                      netwib_ip *pip)
-{
-  netwib_string s;
-  netwib_err ret;
-
-  netwib__buf_ref_string(pbuf, s, bufstorage,
-                         netwib_priv_ip_init_bufnet(&bufstorage, pip));
-
-  ret = netwib_priv_ip_init_sip4(s, NETWIB_TRUE, pip);
-  if (ret == NETWIB_ERR_OK) return(NETWIB_ERR_OK);
-  if (ret != NETWIB_ERR_NOTCONVERTED) return(ret);
-
-  netwib_er(netwib_ip_init_buf_best(pbuf, pip));
-  return(NETWIB_ERR_OK);
-}
-
 /*-------------------------------------------------------------*/
 netwib_err netwib_priv_ip_buf_append_ip4(netwib_constip *pip,
                                          netwib_buf *pbuf)
@@ -613,7 +620,7 @@ netwib_err netwib_priv_ip_buf_append_hn(netwib_constip *pip,
 #if NETWIBDEF_HAVEFUNC_GETNAMEINFO == 1
   {
     netwib_priv_sockaddr_align sa;
-    netwib_uint32 salen;
+    netwib_priv_sockaddr_len salen;
     char *host;
     int reti;
 
@@ -901,10 +908,10 @@ netwib_err netwib_priv_ip_ip6_supported(netwib_bool *pyes)
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_priv_ip_init_maskprefix(netwib_constip *pip,
-                                          netwib_constip *pmask,
-                                          netwib_uint32 prefix,
-                                          netwib_ip *pipm)
+netwib_err netwib_priv_ip_net_init_ipmaskprefix(netwib_constip *pip,
+                                                netwib_constip *pmask,
+                                                netwib_uint32 prefix,
+                                                netwib_ip *pnet)
 {
   netwib_ip ipm;
   netwib_uint32 numbit, masktmp, i;
@@ -933,19 +940,19 @@ netwib_err netwib_priv_ip_init_maskprefix(netwib_constip *pip,
       return(NETWIB_ERR_PAIPTYPE);
   }
 
-  if (pipm != NULL) {
-    *pipm = ipm;
+  if (pnet != NULL) {
+    *pnet = ipm;
   }
 
   return(NETWIB_ERR_OK);
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_priv_ip_cmp_maskprefix(netwib_constip *pip1,
-                                         netwib_constip *pip2,
-                                         netwib_constip *pmask,
-                                         netwib_uint32 prefix,
-                                         netwib_cmp *pcmp)
+netwib_err netwib_priv_ip_net_cmp_ipmaskprefix(netwib_constip *pip1,
+                                               netwib_constip *pip2,
+                                               netwib_constip *pmask,
+                                               netwib_uint32 prefix,
+                                               netwib_cmp *pcmp)
 {
   netwib_ip ip1m, ip2m;
 
@@ -958,8 +965,8 @@ netwib_err netwib_priv_ip_cmp_maskprefix(netwib_constip *pip1,
     return(NETWIB_ERR_OK);
   }
 
-  netwib_er(netwib_priv_ip_init_maskprefix(pip1, pmask, prefix, &ip1m));
-  netwib_er(netwib_priv_ip_init_maskprefix(pip2, pmask, prefix, &ip2m));
+  netwib_er(netwib_priv_ip_net_init_ipmaskprefix(pip1, pmask, prefix, &ip1m));
+  netwib_er(netwib_priv_ip_net_init_ipmaskprefix(pip2, pmask, prefix, &ip2m));
   netwib_er(netwib_ip_cmp(&ip1m, &ip2m, pcmp));
 
   return(NETWIB_ERR_OK);
@@ -979,7 +986,9 @@ netwib_err netwib_priv_ip_maskprefix_init_ipnet(netwib_constip *pip,
                                                 netwib_ip *pmask,
                                                 netwib_uint32 *pprefix)
 {
-  netwib_byte arrayip[4], arraynet[4], arraymask[4];
+  netwib_byte arrayip[NETWIB_IP4_LEN], arraynet[NETWIB_IP4_LEN];
+  netwib_byte arraymask4[NETWIB_IP4_LEN];
+  netwib_uint16 arraymask6[NETWIB_IP6_LEN/2];
   netwib_uint32 i, j, prefix, ipui, netui;
   netwib_bool copyend;
 
@@ -987,6 +996,7 @@ netwib_err netwib_priv_ip_maskprefix_init_ipnet(netwib_constip *pip,
     return(NETWIB_ERR_PAIPTYPE);
   }
 
+  prefix = 0;
   switch(pip->iptype) {
     case NETWIB_IPTYPE_IP4 :
       arrayip[0] = netwib_c2_uint32_0(pip->ipvalue.ip4);
@@ -998,20 +1008,22 @@ netwib_err netwib_priv_ip_maskprefix_init_ipnet(netwib_constip *pip,
       arraynet[2] = netwib_c2_uint32_2(pnet->ipvalue.ip4);
       arraynet[3] = netwib_c2_uint32_3(pnet->ipvalue.ip4);
       copyend = NETWIB_FALSE;
-      for (i = 0; i < 4; i++) {
+      for (i = 0; i < NETWIB_IP4_LEN; i++) {
         if (copyend) {
-          arraymask[i] = 0;
+          arraymask4[i] = 0;
         } else {
           if (arrayip[i] == arraynet[i]) {
-            arraymask[i] = 255;
+            arraymask4[i] = 255;
+            prefix += 8;
           } else {
             copyend = NETWIB_TRUE;
             if (arraynet[i] == 0) {
-              arraymask[i] = 0;
+              arraymask4[i] = 0;
             } else {
               for (j = 0; j < 8; j++) {
                 if (arraynet[i] & (1<<j)) {
-                  arraymask[i] = (netwib_byte)(~((1<<j) - 1));
+                  arraymask4[i] = (netwib_byte)(~((1<<j) - 1));
+                  prefix += 8 - j;
                   break;
                 }
               }
@@ -1021,41 +1033,58 @@ netwib_err netwib_priv_ip_maskprefix_init_ipnet(netwib_constip *pip,
       }
       if (pmask != NULL) {
         pmask->iptype = NETWIB_IPTYPE_IP4;
-        pmask->ipvalue.ip4 = netwib_c2_uint32_4(arraymask[0], arraymask[1],
-                                               arraymask[2], arraymask[3]);
+        pmask->ipvalue.ip4 = netwib_c2_uint32_4(arraymask4[0], arraymask4[1],
+                                                arraymask4[2], arraymask4[3]);
       }
       break;
     case NETWIB_IPTYPE_IP6 :
-      prefix = 0;
-      for (i = 0; i < NETWIB_IP6_LEN; i+=2) {
-        ipui = pip->ipvalue.ip6.b[i] + pip->ipvalue.ip6.b[i+1];
-        netui = pnet->ipvalue.ip6.b[i] + pnet->ipvalue.ip6.b[i+1];
-        if (ipui == netui) {
-          prefix += 16;
+      /* we have to use 16 bits because IPv6 addresses are separated in
+         16 bit blocks */
+      copyend = NETWIB_FALSE;
+      for (i = 0; i < NETWIB_IP6_LEN / 2; i++) {
+        ipui = netwib_c2_uint16_2(pip->ipvalue.ip6.b[2*i], pip->ipvalue.ip6.b[2*i+1]);
+        netui = netwib_c2_uint16_2(pnet->ipvalue.ip6.b[2*i], pnet->ipvalue.ip6.b[2*i+1]);
+        if (copyend) {
+          arraymask6[i] = 0;
         } else {
-          if (netui != 0) {
-            for (j = 0; j < 16; j++) {
-              if (netui & (1<<j)) {
-                prefix += 16 - j;
-                break;
+          if (ipui == netui) {
+            arraymask6[i] = 0xFFFF;
+            prefix += 16;
+          } else {
+            copyend = NETWIB_TRUE;
+            if (netui == 0) {
+              arraymask6[i] = 0;
+            } else {
+              for (j = 0; j < 16; j++) {
+                if (netui & (1<<j)) {
+                  arraymask6[i] = (netwib_uint16)(~((1<<j) - 1));
+                  prefix += 16 - j;
+                  break;
+                }
               }
             }
           }
-          break;
         }
       }
-      if (pprefix != NULL) *pprefix = prefix;
+      if (pmask != NULL) {
+        pmask->iptype = NETWIB_IPTYPE_IP6;
+        for (i = 0; i < NETWIB_IP6_LEN / 2; i++) {
+          pmask->ipvalue.ip6.b[2*i] = netwib_c2_uint16_0(arraymask6[i]);
+          pmask->ipvalue.ip6.b[2*i+1] = netwib_c2_uint16_1(arraymask6[i]);
+        }
+      }
       break;
     default :
       return(NETWIB_ERR_PAIPTYPE);
   }
 
+  if (pprefix != NULL) *pprefix = prefix;
   return(NETWIB_ERR_OK);
 }
 
 /*-------------------------------------------------------------*/
 netwib_err netwib_priv_ip_maskprefix_init_sali(const netwib_priv_sockaddr_unalign *psa,
-                                               netwib_uint32 supposedsalen,
+                                               netwib_priv_sockaddr_len supposedsalen,
                                                netwib_iptype supposediptype,
                                                netwib_ip *pmask,
                                                netwib_uint32 *pprefix)
@@ -1068,13 +1097,178 @@ netwib_err netwib_priv_ip_maskprefix_init_sali(const netwib_priv_sockaddr_unalig
     *pmask = mask;
   }
   if (pprefix != NULL) {
-    if (mask.iptype == NETWIB_IPTYPE_IP6) {
-      netwib_er(netwib_priv_ip_prefix_init_mask(&mask, pprefix));
+    netwib_er(netwib_priv_ip_prefix_init_mask(&mask, pprefix));
+  }
+
+  return(NETWIB_ERR_OK);
+}
+
+/*-------------------------------------------------------------*/
+netwib_err netwib_priv_ip_maskprefix_init_prefix(netwib_iptype iptype,
+                                                 netwib_uint32 prefix,
+                                                 netwib_ip *pmask,
+                                                 netwib_uint32 *pprefix)
+{
+  netwib_uint32 numfull, numbit, i;
+
+  switch(iptype) {
+    case NETWIB_IPTYPE_IP4 :
+      if (prefix > 8*NETWIB_IP4_LEN) {
+        return(NETWIB_ERR_PATOOHIGH);
+      }
+      netwib_er(netwib_ip_init_ip4(~ ( (1 << (32-prefix)) - 1), pmask));
+      break;
+    case NETWIB_IPTYPE_IP6 :
+      if (prefix > 8*NETWIB_IP6_LEN) {
+        return(NETWIB_ERR_PATOOHIGH);
+      }
+      if (pmask != NULL) {
+        pmask->iptype = NETWIB_IPTYPE_IP6;
+        numfull = prefix / 8;
+        numbit = prefix % 8;
+        for (i = 0; i < numfull; i++) {
+          pmask->ipvalue.ip6.b[i] = 0xFF;
+        }
+        if (numbit) {
+          pmask->ipvalue.ip6.b[i] = (netwib_byte)(~ ( (1 << (8-numbit)) - 1));
+          i++;
+        }
+        for (; i < NETWIB_IP6_LEN; i++) {
+          pmask->ipvalue.ip6.b[i] = 0;
+        }
+      }
+      break;
+    default :
+      return(NETWIB_ERR_PAIPTYPE);
+  }
+  if (pprefix != NULL) {
+    *pprefix = prefix;
+  }
+
+  return(NETWIB_ERR_OK);
+}
+
+/*-------------------------------------------------------------*/
+/* pbuf="1.2.3.4" => pnet=1.2.3.4, pmask=255.255.255.255
+   pbuf="1.2.3" => pnet=1.2.3.0, pmask=255.255.255.0 (guess)
+*/
+static netwib_err netwib_priv_ip_netmaskprefix_init_bufnet(netwib_constbuf *pbuf,
+                                                           netwib_ip *pnet,
+                                                           netwib_ip *pmask,
+                                                           netwib_uint32 *pprefix)
+{
+  netwib_string s;
+  netwib_ip net;
+  netwib_uint32 prefix;
+  netwib_err ret;
+
+  /* try with "1.2.3" */
+  netwib__buf_ref_string(pbuf, s, bufstorage,
+                         netwib_priv_ip_netmaskprefix_init_bufnet(&bufstorage, pnet, pmask, pprefix));
+  ret = netwib_priv_ip_netmaskprefix_init_sip4(s, NETWIB_TRUE, pnet, pmask,
+                                               pprefix);
+  if (ret == NETWIB_ERR_OK) return(NETWIB_ERR_OK);
+  if (ret != NETWIB_ERR_NOTCONVERTED) return(ret);
+
+  /* try with "1.2.3.4", or an IPv6 address */
+  netwib_er(netwib_ip_init_buf(pbuf, NETWIB_IP_DECODETYPE_IP, &net));
+  prefix = 8* ((net.iptype==NETWIB_IPTYPE_IP4)?NETWIB_IP4_LEN:NETWIB_IP6_LEN);
+  netwib_er(netwib_priv_ip_maskprefix_init_prefix(net.iptype, prefix,
+                                                  pmask, pprefix));
+  if (pnet != NULL) {
+    *pnet = net;
+  }
+
+  return(NETWIB_ERR_OK);
+}
+
+/*-------------------------------------------------------------*/
+netwib_err netwib_priv_ip_netmaskprefix_init_buf(netwib_constbuf *pbuf,
+                                                 netwib_ip *pnet,
+                                                 netwib_ip *pmask,
+                                                 netwib_uint32 *pprefix)
+{
+  netwib_buf bufnet;
+  netwib_ip net, mask;
+  netwib_uint32 prefix=0;
+  netwib_bool foundmask, foundprefix;
+  netwib_err ret;
+
+  netwib_er(netwib_buf_init_mallocdefault(&bufnet));
+
+  /* obtain "net/mask", "net/prefix" or "net" */
+  foundmask = NETWIB_FALSE;
+  foundprefix = NETWIB_FALSE;
+  ret = netwib_buf_decode_fmt(pbuf, "%{buf}/%{ip}%$", &bufnet, &mask);
+  if (ret == NETWIB_ERR_OK) {
+    foundmask = NETWIB_TRUE;
+  } else {
+    netwib__buf_reinit(&bufnet);
+    ret = netwib_buf_decode_fmt(pbuf, "%{buf}/%{uint32}%$", &bufnet, &prefix);
+    if (ret == NETWIB_ERR_OK) {
+      foundprefix = NETWIB_TRUE;
     } else {
-      *pprefix = 0;
+      netwib_er(netwib_buf_append_buf(pbuf, &bufnet));
     }
   }
 
+  /* convert net */
+  ret = netwib_priv_ip_netmaskprefix_init_bufnet(&bufnet, &net, pmask,
+                                                 pprefix);
+  if (ret == NETWIB_ERR_OK) {
+    if (pnet != NULL) {
+      *pnet = net;
+    }
+    if (foundmask) {
+      if (pmask != NULL) {
+        *pmask = mask;
+      }
+      if (pprefix != NULL) {
+        ret = netwib_priv_ip_prefix_init_mask(&mask, pprefix);
+      }
+    }
+    if (foundprefix) {
+      ret = netwib_priv_ip_maskprefix_init_prefix(net.iptype, prefix,
+                                                  pmask, pprefix);
+    }
+  }
+
+  netwib_er(netwib_buf_close(&bufnet));
+
+  return(ret);
+}
+
+/*-------------------------------------------------------------*/
+netwib_err netwib_priv_ip_netmaskprefix_init_bufdefault(netwib_iptype iptype,
+                                                        netwib_constbuf *pbuf,
+                                                        netwib_ip *pnet,
+                                                        netwib_ip *pmask,
+                                                       netwib_uint32 *pprefix)
+{
+  netwib_cmp cmp;
+
+  netwib_er(netwib_buf_cmp_str(pbuf, "default", &cmp));
+  if (cmp == NETWIB_CMP_EQ) {
+    switch(iptype) {
+    case NETWIB_IPTYPE_IP4 :
+      netwib_er(netwib_ip_init_ip4_fields(0,0,0,0, pnet));
+      netwib_er(netwib_ip_init_ip4_fields(0,0,0,0, pmask));
+      if (pprefix != NULL) *pprefix = 0;
+      return(NETWIB_ERR_OK);
+      break;
+    case NETWIB_IPTYPE_IP6 :
+      netwib_er(netwib_ip_init_ip6_fields(0,0,0,0, pnet));
+      netwib_er(netwib_ip_init_ip6_fields(0,0,0,0, pmask));
+      if (pprefix != NULL) *pprefix = 0;
+      return(NETWIB_ERR_OK);
+      break;
+    default :
+      return(NETWIB_ERR_PAIPTYPE);
+    }
+  }
+
+  netwib_er(netwib_priv_ip_netmaskprefix_init_buf(pbuf, pnet, pmask, pprefix));
+
   return(NETWIB_ERR_OK);
 }
 
@@ -1084,26 +1278,24 @@ netwib_err netwib_priv_ip_prefix_init_mask(netwib_constip *pmask,
 {
   netwib_uint32 prefix, i;
 
-  if (pmask->iptype != NETWIB_IPTYPE_IP6) {
-    return(NETWIB_ERR_PAIPTYPENOT6);
-  }
+#define NETWIB_PRIV_IP_PREFIX_INIT_MASK(w,x,n) if (((w) & (x)) == (x)) {prefix += n; break;}
+#define NETWIB_PRIV_IP_PREFIX_INIT_MASK2(w) { if (w != 0xFF) { NETWIB_PRIV_IP_PREFIX_INIT_MASK(w, 0xFE, 7); NETWIB_PRIV_IP_PREFIX_INIT_MASK(w, 0xFC, 6); NETWIB_PRIV_IP_PREFIX_INIT_MASK(w, 0xF8, 5); NETWIB_PRIV_IP_PREFIX_INIT_MASK(w, 0xF0, 4); NETWIB_PRIV_IP_PREFIX_INIT_MASK(w, 0xE0, 3); NETWIB_PRIV_IP_PREFIX_INIT_MASK(w, 0xC0, 2); NETWIB_PRIV_IP_PREFIX_INIT_MASK(w, 0x80, 1); NETWIB_PRIV_IP_PREFIX_INIT_MASK(w, 0x00, 0); } prefix += 8; }
 
   prefix = 0;
-  for (i = 0; i < NETWIB_IP6_LEN; i++) {
-    if (pmask->ipvalue.ip6.b[i] != 0xFF) {
-      switch(pmask->ipvalue.ip6.b[i]) {
-      case 0 : break;
-      case 0xFE : prefix += 7; break;
-      case 0xFC : prefix += 6; break;
-      case 0xF8 : prefix += 5; break;
-      case 0xF0 : prefix += 4; break;
-      case 0xE0 : prefix += 3; break;
-      case 0xC0 : prefix += 2; break;
-      case 0x80 : prefix += 1; break;
+  switch(pmask->iptype) {
+    case NETWIB_IPTYPE_IP4 :
+      NETWIB_PRIV_IP_PREFIX_INIT_MASK2(netwib_c2_uint32_0(pmask->ipvalue.ip4));
+      NETWIB_PRIV_IP_PREFIX_INIT_MASK2(netwib_c2_uint32_1(pmask->ipvalue.ip4));
+      NETWIB_PRIV_IP_PREFIX_INIT_MASK2(netwib_c2_uint32_2(pmask->ipvalue.ip4));
+      NETWIB_PRIV_IP_PREFIX_INIT_MASK2(netwib_c2_uint32_3(pmask->ipvalue.ip4));
+      break;
+    case NETWIB_IPTYPE_IP6 :
+      for (i = 0; i < NETWIB_IP6_LEN; i++) {
+        NETWIB_PRIV_IP_PREFIX_INIT_MASK2(pmask->ipvalue.ip6.b[i]);
       }
       break;
-    }
-    prefix += 8;
+    default :
+      return(NETWIB_ERR_PAIPTYPE);
   }
 
   if (pprefix != NULL) *pprefix = prefix;
