@@ -334,7 +334,7 @@ static netwib_err netwib_priv_ips_add_str_hns(netwib_priv_ranges *pr,
     pcur = pres;
     while(pcur != NULL) {
       psa = pcur->ai_addr;
-      ret = netwib_priv_sa_ip_init_sa((const netwib_priv_sockaddr *)psa, &ipa);
+      ret = netwib_priv_sa_ip_init_sa((const netwib_priv_sockaddr_unalign *)psa, &ipa);
       if (ret == NETWIB_ERR_OK) {
         ret = netwib_priv_ips_array_init_ip(&ipa, array);
         if (ret == NETWIB_ERR_OK) {
