@@ -2,7 +2,8 @@
 */
 
 /*-------------------------------------------------------------*/
-static netwib_err netwib_priv_libpcap_notcompiled(void)
+netwib_err netwib_priv_libpcap_notcompiled(void);
+netwib_err netwib_priv_libpcap_notcompiled(void)
 {
 #if defined NETWIBDEF_SYSNAME_Unix
   netwib_er(netwib_priv_errmsg_text("netwib wasn't compiled with libpcap support"));
@@ -12,13 +13,12 @@ static netwib_err netwib_priv_libpcap_notcompiled(void)
  #error "Unknown value for NETWIBDEF_SYSNAME"
 #endif
   return(NETWIB_ERR_OK);
-  netwib_priv_libpcap_notcompiled();
 }
-static netwib_err netwib_priv_winpcap_notavail(void)
+netwib_err netwib_priv_winpcap_notavail(void);
+netwib_err netwib_priv_winpcap_notavail(void)
 {
   netwib_er(netwib_priv_errmsg_text("WinPCAP >= 3.0 is not found"));
   return(NETWIB_ERR_OK);
-  netwib_priv_winpcap_notavail();
 }
 
 /*-------------------------------------------------------------*/
@@ -111,9 +111,9 @@ netwib_err netwib_priv_libpcap_init_sniff(netwib_constbuf *pdevice,
 #else
 {
   netwib_er(netwib_priv_libpcap_notcompiled());
+  pdevice = pdevice; /* for compiler warning */
+  plib = plib; /* for compiler warning */
   return(NETWIB_ERR_LONOTSUPPORTED);
-  pdevice = pdevice;
-  plib = plib;
 }
 #endif
 
@@ -148,9 +148,9 @@ netwib_err netwib_priv_libpcap_init_read(netwib_constbuf *pfilename,
 #else
 {
   netwib_er(netwib_priv_libpcap_notcompiled());
+  pfilename = pfilename; /* for compiler warning */
+  plib = plib; /* for compiler warning */
   return(NETWIB_ERR_LONOTSUPPORTED);
-  pfilename = pfilename;
-  plib = plib;
 }
 #endif
 
@@ -238,9 +238,9 @@ netwib_err netwib_priv_libpcap_init_write(netwib_constbuf *pfilename,
 #else
 {
   netwib_er(netwib_priv_libpcap_notcompiled());
+  pfilename = pfilename; /* for compiler warning */
+  plib = plib; /* for compiler warning */
   return(NETWIB_ERR_LONOTSUPPORTED);
-  pfilename = pfilename;
-  plib = plib;
 }
 #endif
 
@@ -274,8 +274,8 @@ netwib_err netwib_priv_libpcap_close(netwib_priv_libpcap *plib)
 #else
 {
   netwib_er(netwib_priv_libpcap_notcompiled());
+  plib = plib; /* for compiler warning */
   return(NETWIB_ERR_LONOTSUPPORTED);
-  plib = plib;
 }
 #endif
 
@@ -321,9 +321,9 @@ netwib_err netwib_priv_libpcap_set_filter(netwib_priv_libpcap *plib,
 #else
 {
   netwib_er(netwib_priv_libpcap_notcompiled());
+  plib = plib; /* for compiler warning */
+  pfilter = pfilter; /* for compiler warning */
   return(NETWIB_ERR_LONOTSUPPORTED);
-  plib = plib;
-  pfilter = pfilter;
 }
 #endif
 
@@ -369,6 +369,7 @@ netwib_err netwib_priv_libpcap_set_nonblock(netwib_priv_libpcap *plib)
   }
  #endif
 #elif defined NETWIBDEF_SYSNAME_HPUX
+#elif defined NETWIBDEF_SYSNAME_Tru64UNIX
 #elif defined NETWIBDEF_SYSNAME_Linux
 #elif defined NETWIBDEF_SYSNAME_Windows
 #elif defined NETWIBDEF_SYSNAME_Unsupported
@@ -381,14 +382,14 @@ netwib_err netwib_priv_libpcap_set_nonblock(netwib_priv_libpcap *plib)
 # error "Unknown value for NETWIBDEF_SYSNAME"
 #endif
 
+  plib = plib; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  plib = plib;
 }
 #else
 {
   netwib_er(netwib_priv_libpcap_notcompiled());
+  plib = plib; /* for compiler warning */
   return(NETWIB_ERR_LONOTSUPPORTED);
-  plib = plib;
 }
 #endif
 
@@ -539,8 +540,8 @@ netwib_err netwib_priv_libpcap_get_dlt(netwib_priv_libpcap *plib)
 #else
 {
   netwib_er(netwib_priv_libpcap_notcompiled());
+  plib = plib; /* for compiler warning */
   return(NETWIB_ERR_LONOTSUPPORTED);
-  plib = plib;
 }
 #endif
 
@@ -603,9 +604,9 @@ netwib_err netwib_priv_libpcap_read(netwib_priv_libpcap *plib,
 #else
 {
   netwib_er(netwib_priv_libpcap_notcompiled());
+  plib = plib; /* for compiler warning */
+  pbuf = pbuf; /* for compiler warning */
   return(NETWIB_ERR_LONOTSUPPORTED);
-  plib = plib;
-  pbuf = pbuf;
 }
 #endif
 
@@ -636,9 +637,9 @@ netwib_err netwib_priv_libpcap_write(netwib_priv_libpcap *plib,
 #else
 {
   netwib_er(netwib_priv_libpcap_notcompiled());
+  plib = plib; /* for compiler warning */
+  pbuf = pbuf; /* for compiler warning */
   return(NETWIB_ERR_LONOTSUPPORTED);
-  plib = plib;
-  pbuf = pbuf;
 }
 #endif
 
@@ -707,11 +708,11 @@ netwib_err netwib_priv_libpcap_wait(netwib_priv_libpcap *plib,
 #else
 {
   netwib_er(netwib_priv_libpcap_notcompiled());
+  plib = plib; /* for compiler warning */
+  way = way; /* for compiler warning */
+  pabstime = pabstime; /* for compiler warning */
+  pevent = pevent; /* for compiler warning */
   return(NETWIB_ERR_LONOTSUPPORTED);
-  plib = plib;
-  way = way;
-  pabstime = pabstime;
-  pevent = pevent;
 }
 #endif
 
