@@ -15,26 +15,26 @@
       is also IPv4).
 */
 static netwib_err netwib_priv_sa_info(const netwib_priv_sockaddr_unalign *psa,
-                                      netwib_uint32 supposedsalen,
+                                      netwib_priv_sockaddr_len supposedsalen,
                                       netwib_iptype supposediptype,
                                       netwib_uint32 *pguessedsafamily,
-                                      netwib_uint32 *pguessedsalen)
+                                      netwib_priv_sockaddr_len *pguessedsalen)
 {
   struct sockaddr ssa;
-  netwib_uint32 guessedsalen, guessedsafamily, sizetocopy;
+  netwib_uint32 guessedsafamily, sizetocopy;
+  netwib_priv_sockaddr_len guessedsalen;
 
   /* copy only beginning (only used here) */
-#if defined NETWIBDEF_SYSNAME_BSD
-  sizetocopy = sizeof(ssa.sa_family) + sizeof(ssa.sa_len);
-#else
   sizetocopy = sizeof(ssa.sa_family);
+#if NETWIBDEF_HAVEFIELD_SOCKADDR_SALEN == 1
+  sizetocopy += sizeof(ssa.sa_len);
 #endif
   netwib_c_memcpy(&ssa, psa, sizetocopy);
 
   /* first step of salen guessing: user value is priority over
      BSD field value */
   guessedsalen = supposedsalen;
-#if defined NETWIBDEF_SYSNAME_BSD
+#if NETWIBDEF_HAVEFIELD_SOCKADDR_SALEN == 1
   if (supposedsalen == 0xFFFFFFFFu) {
     /* user does not know length, so take header value */
     guessedsalen = ssa.sa_len;
@@ -60,10 +60,10 @@ static netwib_err netwib_priv_sa_info(const netwib_priv_sockaddr_unalign *psa,
   /* if family is valid, ensure salen is valid */
   switch(guessedsafamily) {
   case AF_INET :
-    if (guessedsalen == 0xFFFFFFFFu) {
+    if ((netwib_uint32)guessedsalen == 0xFFFFFFFFu) {
       guessedsalen = sizeof(struct sockaddr_in);
     } else {
-      if (guessedsalen > sizeof(struct sockaddr_in)) {
+      if ((netwib_uint32)guessedsalen > (netwib_uint32)sizeof(struct sockaddr_in)) {
         guessedsalen = sizeof(struct sockaddr_in);
       }
     }
@@ -73,10 +73,10 @@ static netwib_err netwib_priv_sa_info(const netwib_priv_sockaddr_unalign *psa,
 #if NETWIBDEF_HAVETYPE_SOCKADDR_IN6 == 1
  #if NETWIBDEF_HAVEVAR_AF_INET6 == 1
   case AF_INET6 :
-    if (guessedsalen == 0xFFFFFFFFu) {
+    if ((netwib_uint32)guessedsalen == 0xFFFFFFFFu) {
       guessedsalen = sizeof(struct sockaddr_in6);
     } else {
-      if (guessedsalen > sizeof(struct sockaddr_in6)) {
+      if ((netwib_uint32)guessedsalen > sizeof(struct sockaddr_in6)) {
         guessedsalen = sizeof(struct sockaddr_in6);
       }
     }
@@ -87,15 +87,15 @@ static netwib_err netwib_priv_sa_info(const netwib_priv_sockaddr_unalign *psa,
 #endif
   case 0 :
     /* try to guess family from salen */
-    if (guessedsalen == 0xFFFFFFFFu) {
+    if ((netwib_uint32)guessedsalen == 0xFFFFFFFFu) {
       return(NETWIB_ERR_PAIPTYPE);
     } else {
-      if (guessedsalen <= sizeof(struct sockaddr_in)) {
+      if ((netwib_uint32)guessedsalen <= sizeof(struct sockaddr_in)) {
         *pguessedsafamily = AF_INET;
         *pguessedsalen = guessedsalen;
 #if NETWIBDEF_HAVETYPE_SOCKADDR_IN6 == 1
  #if NETWIBDEF_HAVEVAR_AF_INET6 == 1
-      } else if (guessedsalen <= sizeof(struct sockaddr_in6)) {
+      } else if ((netwib_uint32)guessedsalen <= sizeof(struct sockaddr_in6)) {
         *pguessedsafamily = AF_INET6;
         *pguessedsalen = guessedsalen;
       } else if (guessedsalen == AF_INET6) {
@@ -119,7 +119,7 @@ static netwib_err netwib_priv_sa_info(const netwib_priv_sockaddr_unalign *psa,
 
 /*-------------------------------------------------------------*/
 netwib_err netwib_priv_sa_ipport_init_sali(const netwib_priv_sockaddr_unalign *psa,
-                                           netwib_uint32 supposedsalen,
+                                           netwib_priv_sockaddr_len supposedsalen,
                                            netwib_iptype supposediptype,
                                            netwib_ip *pip,
                                            netwib_port *pport)
@@ -128,7 +128,8 @@ netwib_err netwib_priv_sa_ipport_init_sali(const netwib_priv_sockaddr_unalign *p
 #if NETWIBDEF_HAVETYPE_SOCKADDR_IN6 == 1
   struct sockaddr_in6 sain6;
 #endif
-  netwib_uint32 safamily, salen;
+  netwib_uint32 safamily;
+  netwib_priv_sockaddr_len salen;
 
   netwib_er(netwib_priv_sa_info(psa, supposedsalen, supposediptype,
                                 &safamily, &salen));
@@ -189,7 +190,7 @@ netwib_err netwib_priv_sa_sal_init_iptport(netwib_constip *pip,
                                            netwib_iptype iptype,
                                            netwib_port port,
                                            netwib_priv_sockaddr_align *psa,
-                                           netwib_uint32 *psalen)
+                                           netwib_priv_sockaddr_len *psalen)
 {
   struct sockaddr_in sain;
 #if NETWIBDEF_HAVETYPE_SOCKADDR_IN6 == 1
@@ -204,7 +205,7 @@ netwib_err netwib_priv_sa_sal_init_iptport(netwib_constip *pip,
   case NETWIB_IPTYPE_IP4 :
     if (psa != NULL) {
       netwib_c_memset(&sain, 0, sizeof(struct sockaddr_in));
- #if defined NETWIBDEF_SYSNAME_BSD
+ #if NETWIBDEF_HAVEFIELD_SOCKADDRIN_SINLEN == 1
       sain.sin_len = sizeof(struct sockaddr_in);
  #endif
       sain.sin_family = AF_INET;
@@ -225,7 +226,7 @@ netwib_err netwib_priv_sa_sal_init_iptport(netwib_constip *pip,
   case NETWIB_IPTYPE_IP6 :
     if (psa != NULL) {
       netwib_c_memset(&sain6, 0, sizeof(struct sockaddr_in6));
- #if defined NETWIBDEF_SYSNAME_BSD
+ #if NETWIBDEF_HAVEFIELD_SOCKADDRIN6_SIN6LEN == 1
       sain6.sin6_len = sizeof(struct sockaddr_in6);
  #endif
       sain6.sin6_family = AF_INET6;
@@ -290,7 +291,7 @@ netwib_err netwib_priv_sa_send(int fd,
 netwib_err netwib_priv_sa_sendto(int fd,
                                  netwib_constbuf *pbuf,
                                  const netwib_priv_sockaddr_unalign *psa,
-                                 netwib_uint32 salen)
+                                 netwib_priv_sockaddr_len salen)
 {
   netwib_priv_sockaddr_align saalign;
   netwib_data data;
@@ -300,7 +301,7 @@ netwib_err netwib_priv_sa_sendto(int fd,
   data = netwib__buf_ref_data_ptr(pbuf);
   datasize = netwib__buf_ref_data_size(pbuf);
 
-  if (salen > sizeof(saalign)) {
+  if ((netwib_uint32)salen > sizeof(saalign)) {
     return(NETWIB_ERR_LOINTERNALERROR);
   }
   netwib_c_memcpy(&saalign, psa, salen);
@@ -384,11 +385,11 @@ netwib_err netwib_priv_sa_recv(int fd,
 netwib_err netwib_priv_sa_recvfrom(int fd,
                                    netwib_buf *pbuf,
                                    netwib_priv_sockaddr_align *psa,
-                                   netwib_uint32 *psalen)
+                                   netwib_priv_sockaddr_len *psalen)
 {
   netwib_data data;
   netwib_uint32 maxmsgsize;
-  netwib_c_socklen_t salen;
+  netwib_priv_sockaddr_len salen;
   int readsize;
 
   netwib_er(netwib_buf_wishspace(pbuf, NETWIB_PRIV_MINMSGSIZE_READ,
@@ -439,7 +440,7 @@ netwib_err netwib_priv_sa_recvfrom(int fd,
   }
 
   if (psalen != NULL) {
-    *psalen = (netwib_uint32)salen;
+    *psalen = salen;
   }
 
   /* store read data */
