@@ -1,7 +1,7 @@
 /*
                                   NETWIB
                              Network library
-                Copyright(c) 1999-2005 Laurent Constantin
+                Copyright(c) 1999-2006 Laurent Constantin
                                   -----
 
   Main server    : http://www.laurentconstantin.com/
@@ -58,9 +58,9 @@ static netwib_err netwib_priv_io_sock_init(netwib_io_socktype socktype,
 {
   netwib_data ip4opts;
   netwib_uint32 ip4optssize;
-  netwib_uint32 salen;
-  netwib_err ret;
   netwib_priv_sockaddr_align sa;
+  netwib_priv_sockaddr_len salen;
+  netwib_err ret;
   int reti, sockettype=0, socketproto=0, socketdomain=0, one;
 
   ptr->socktype = socktype;
@@ -262,7 +262,7 @@ static netwib_err netwib_priv_io_sock_read(netwib_io *pio,
 {
   netwib_priv_io_sock *ptr = (netwib_priv_io_sock *)pio->pcommon;
   netwib_priv_sockaddr_align sa;
-  netwib_uint32 salen;
+  netwib_priv_sockaddr_len salen;
   int reti;
 
   switch(ptr->socktype) {
@@ -290,8 +290,7 @@ static netwib_err netwib_priv_io_sock_read(netwib_io *pio,
       break;
     case NETWIB_IO_SOCKTYPE_UDP_MULSER :
       netwib_er(netwib_priv_sa_recvfrom(ptr->fd, pbuf, &sa, &salen));
-      netwib_er(netwib_priv_sa_ipport_init_sal((netwib_priv_sockaddr_unalign*)&sa, salen, &ptr->remoteip,
-                                               &ptr->remoteport));
+      netwib_er(netwib_priv_sa_ipport_init_sal((netwib_priv_sockaddr_unalign*)&sa, salen, &ptr->remoteip, &ptr->remoteport));
       ptr->clientconnected = NETWIB_TRUE;
       break;
   }
@@ -305,7 +304,7 @@ static netwib_err netwib_priv_io_sock_write(netwib_io *pio,
 {
   netwib_priv_io_sock *ptr = (netwib_priv_io_sock *)pio->pcommon;
   netwib_priv_sockaddr_align sa;
-  netwib_uint32 salen;
+  netwib_priv_sockaddr_len salen;
 
   switch(ptr->socktype) {
     case NETWIB_IO_SOCKTYPE_UDP_SER :
@@ -425,7 +424,7 @@ static netwib_err netwib_priv_io_sock_ctl_get(netwib_io *pio,
 {
   netwib_priv_io_sock *ptr = (netwib_priv_io_sock *)pio->pcommon;
   netwib_priv_sockaddr_align sa;
-  netwib_uint32 salen;
+  netwib_priv_sockaddr_len salen;
   int reti;
 
   switch(type) {
@@ -851,9 +850,10 @@ static netwib_err netwib_sock_tcp_mulser2(netwib_constip *plocalip,
 {
   netwib_data ip4opts;
   netwib_uint32 ip4optssize;
-  netwib_uint32 salen, threadid;
+  netwib_uint32 threadid;
   netwib_bool ringset, event;
   netwib_priv_sockaddr_align sa;
+  netwib_priv_sockaddr_len salen;
   netwib_ring *pring;
   netwib_priv_sock_tcp_mulser_info *ptmi;
   netwib_thread *pthread;
