@@ -1,7 +1,7 @@
 /*
                                   NETWIB
                              Network library
-                Copyright(c) 1999-2005 Laurent Constantin
+                Copyright(c) 1999-2006 Laurent Constantin
                                   -----
 
   Main server    : http://www.laurentconstantin.com/
@@ -194,10 +194,8 @@ netwib_err netwib_dirname_exists(netwib_constbuf *pdirname,
     } else {
       exists = NETWIB_FALSE;
     }
-  } else if (ret == NETWIB_ERR_NOTFOUND) {
-    exists = NETWIB_FALSE;
   } else {
-    return(ret);
+    exists = NETWIB_FALSE;
   }
 
   if (pyes != NULL) {
