@@ -293,6 +293,7 @@ typedef enum {
   NETWIB_IO_CTLTYPE_FILE_SEEK_CURRENT,
   NETWIB_IO_CTLTYPE_FILE_SEEK_END,
   NETWIB_IO_CTLTYPE_FILE_TELL,
+  NETWIB_IO_CTLTYPE_FILE_TRUNCATE,
   /* fd : 300 */
   /* handle : 400 */
   /* ipc : 500 */
@@ -310,6 +311,7 @@ typedef enum {
   NETWIB_IO_CTLTYPE_SOCK_LOCAL,
   NETWIB_IO_CTLTYPE_SOCK_REMOTE,
   NETWIB_IO_CTLTYPE_SOCK_MULTICASTTTL,
+  NETWIB_IO_CTLTYPE_SOCK_SOCKTYPE,
   /* sockv : 900 */
   NETWIB_IO_CTLTYPE_SOCKV_ANSWERALIVE = 900,
   /* sniff : 1000 */
