@@ -1,7 +1,7 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2005 Laurent Constantin
+                Copyright(c) 1999-2006 Laurent Constantin
                                   -----
 
   Main server    : http://www.laurentconstantin.com/
@@ -234,12 +234,12 @@ static netwib_err netwox_smbcmdtscq_encode_tsc_plm(const netwox_smbcmd_transacti
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwox_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSHAREENUM_DESCRIPTOR_PARAMETER_12, &cmp));
+    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSHAREENUM_DESCRIPTOR_PARAMETER_12, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwox_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSHAREENUM_DESCRIPTOR_RETURN_1, &cmp));
+    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSHAREENUM_DESCRIPTOR_RETURN_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
@@ -262,12 +262,12 @@ static netwib_err netwox_smbcmdtscq_encode_tsc_plm(const netwox_smbcmd_transacti
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwox_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSHAREGETINFO_DESCRIPTOR_PARAMETER_1, &cmp));
+    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSHAREGETINFO_DESCRIPTOR_PARAMETER_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwox_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSHAREGETINFO_DESCRIPTOR_RETURN_1, &cmp));
+    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSHAREGETINFO_DESCRIPTOR_RETURN_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
@@ -291,12 +291,12 @@ static netwib_err netwox_smbcmdtscq_encode_tsc_plm(const netwox_smbcmd_transacti
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwox_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSERVERGETINFO_DESCRIPTOR_PARAMETER_1, &cmp));
+    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSERVERGETINFO_DESCRIPTOR_PARAMETER_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwox_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSERVERGETINFO_DESCRIPTOR_RETURN_1, &cmp));
+    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSERVERGETINFO_DESCRIPTOR_RETURN_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
@@ -319,12 +319,12 @@ static netwib_err netwox_smbcmdtscq_encode_tsc_plm(const netwox_smbcmd_transacti
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwox_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETWKSTAGETINFO_DESCRIPTOR_PARAMETER_1, &cmp));
+    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETWKSTAGETINFO_DESCRIPTOR_PARAMETER_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwox_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETWKSTAGETINFO_DESCRIPTOR_RETURN_1, &cmp));
+    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETWKSTAGETINFO_DESCRIPTOR_RETURN_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
@@ -347,12 +347,12 @@ static netwib_err netwox_smbcmdtscq_encode_tsc_plm(const netwox_smbcmd_transacti
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwox_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSERVERENUM2_DESCRIPTOR_PARAMETER_1, &cmp));
+    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSERVERENUM2_DESCRIPTOR_PARAMETER_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwox_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSERVERENUM2_DESCRIPTOR_RETURN_1, &cmp));
+    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSERVERENUM2_DESCRIPTOR_RETURN_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
@@ -421,14 +421,14 @@ netwib_err netwox_smbcmdtscq_encode_smbcmd(netwox_constsmbcmd *psmbcmd,
       return(NETWIB_ERR_OK);
     }
   } else {
-    netwib_er(netwox_buf_cmp_str(&psmbcmd->value.transaction_q.name,
+    netwib_er(netwib_buf_cmp_str(&psmbcmd->value.transaction_q.name,
                                  NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN,
                                  &cmp));
     if (cmp == NETWIB_CMP_EQ) {
       netwib_er(netwox_smbcmdtscq_encode_tsc_plm(&psmbcmd->value.transaction_q, psmbcmdtscq));
       return(NETWIB_ERR_OK);
     }
-    netwib_er(netwox_buf_cmp_str(&psmbcmd->value.transaction_q.name,
+    netwib_er(netwib_buf_cmp_str(&psmbcmd->value.transaction_q.name,
                                  NETWOX_SMBCMD_TRANSACTION_NAME_PIPE,
                                  &cmp));
     if (cmp == NETWIB_CMP_EQ) {
