@@ -89,6 +89,9 @@ searchstring ()
     INCL_ASM_PAGE)
      echo "asm/page.h"
      ;;
+    INCL_MACH_MACHINE_VMPARAM)
+     echo "mach/machine/vmparam.h"
+     ;;
     INCL_MACHINE_PARAM)
      echo "machine/param.h"
      ;;
@@ -113,6 +116,18 @@ searchstring ()
     TYPE_SOCKADDR_IN6)
      echo "sockaddr_in6"
      ;;
+    FIELD_TM_GMTOFF)
+     echo "tm_gmtoff"
+     ;;
+    FIELD_SOCKADDR_SALEN)
+     echo "sa_len"
+     ;;
+    FIELD_SOCKADDRIN_SINLEN)
+     echo "sin_len"
+     ;;
+    FIELD_SOCKADDRIN6_SIN6LEN)
+     echo "sin6_len"
+     ;;
     FUNC_ETHER_NTOHOST)
      echo "ether_ntohost"
      ;;
@@ -167,6 +182,9 @@ searchstring ()
     FUNC_CLOCK_GETTIME)
      echo "clock_gettime"
      ;;
+    FUNC_PTHREAD_DELAY_NP)
+     echo "pthread_delay_np"
+     ;;
     FUNC_PTHREAD_MUTEX_TIMEDLOCK)
      echo "pthread_mutex_timedlock"
      ;;
@@ -245,9 +263,6 @@ searchstring ()
     VAR_SC_GETGR_R_SIZE_MAX)
      echo "SC_GETGR_R_SIZE_MAX"
      ;;
-    VAR_TM_GMTOFF)
-     echo "tm_gmtoff"
-     ;;
     *)
      echo "Not found : $var" 1>&2
      exit
