@@ -552,6 +552,146 @@ static netwib_err netwib_buf_cmp_test(void)
   return(NETWIB_ERR_OK);
 }
 
+/*-------------------------------------------------------------*/
+static netwib_err netwib_buf_casecmp_test(void)
+{
+  netwib_buf buf1, buf2;
+  netwib_cmp cmp;
+
+  puts("++++----\nTest of netwib_buf_casecmp");
+  netwib_er(netwib_buf_init_ext_text("heLlo", &buf1));
+  netwib_er(netwib_buf_init_ext_text("hEllo", &buf2));
+  netwib_er(netwib_buf_casecmp(&buf1, &buf2, &cmp));
+  if (cmp != NETWIB_CMP_EQ) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_init_ext_text("hell_O", &buf1));
+  netwib_er(netwib_buf_init_ext_text("hEll_p", &buf2));
+  netwib_er(netwib_buf_casecmp(&buf1, &buf2, &cmp));
+  if (cmp != NETWIB_CMP_LT) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_init_ext_text("heLlo", &buf1));
+  netwib_er(netwib_buf_init_ext_text("hEll", &buf2));
+  netwib_er(netwib_buf_casecmp(&buf1, &buf2, &cmp));
+  if (cmp != NETWIB_CMP_GT) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_init_ext_empty(&buf1));
+  netwib_er(netwib_buf_init_ext_text("heLl", &buf2));
+  netwib_er(netwib_buf_casecmp(&buf1, &buf2, &cmp));
+  if (cmp != NETWIB_CMP_LT) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_init_ext_empty(&buf1));
+  netwib_er(netwib_buf_init_ext_empty(&buf2));
+  netwib_er(netwib_buf_casecmp(&buf1, &buf2, &cmp));
+  if (cmp != NETWIB_CMP_EQ) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_casecmp(NULL, NULL, &cmp));
+  if (cmp != NETWIB_CMP_EQ) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  return(NETWIB_ERR_OK);
+}
+
+/*-------------------------------------------------------------*/
+static netwib_err netwib_buf_cmp_str_test(void)
+{
+  netwib_buf buf1;
+  netwib_cmp cmp;
+
+  puts("++++----\nTest of netwib_buf_cmp_str");
+  netwib_er(netwib_buf_init_ext_text("hello", &buf1));
+  netwib_er(netwib_buf_cmp_str(&buf1, "hello", &cmp));
+  if (cmp != NETWIB_CMP_EQ) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_init_ext_text("hell_o", &buf1));
+  netwib_er(netwib_buf_cmp_str(&buf1, "hell_p", &cmp));
+  if (cmp != NETWIB_CMP_LT) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_init_ext_text("hello", &buf1));
+  netwib_er(netwib_buf_cmp_str(&buf1, "hell", &cmp));
+  if (cmp != NETWIB_CMP_GT) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_init_ext_empty(&buf1));
+  netwib_er(netwib_buf_cmp_str(&buf1, "hell", &cmp));
+  if (cmp != NETWIB_CMP_LT) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_init_ext_empty(&buf1));
+  netwib_er(netwib_buf_cmp_str(&buf1, "", &cmp));
+  if (cmp != NETWIB_CMP_EQ) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_cmp_str(NULL, "", &cmp));
+  if (cmp != NETWIB_CMP_EQ) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  return(NETWIB_ERR_OK);
+}
+
+/*-------------------------------------------------------------*/
+static netwib_err netwib_buf_casecmp_str_test(void)
+{
+  netwib_buf buf1;
+  netwib_cmp cmp;
+
+  puts("++++----\nTest of netwib_buf_casecmp_str");
+  netwib_er(netwib_buf_init_ext_text("hEllo", &buf1));
+  netwib_er(netwib_buf_casecmp_str(&buf1, "heLlo", &cmp));
+  if (cmp != NETWIB_CMP_EQ) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_init_ext_text("hEll_o", &buf1));
+  netwib_er(netwib_buf_casecmp_str(&buf1, "hell_p", &cmp));
+  if (cmp != NETWIB_CMP_LT) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_init_ext_text("hello", &buf1));
+  netwib_er(netwib_buf_casecmp_str(&buf1, "heLl", &cmp));
+  if (cmp != NETWIB_CMP_GT) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_init_ext_empty(&buf1));
+  netwib_er(netwib_buf_casecmp_str(&buf1, "heLl", &cmp));
+  if (cmp != NETWIB_CMP_LT) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_init_ext_empty(&buf1));
+  netwib_er(netwib_buf_casecmp_str(&buf1, "", &cmp));
+  if (cmp != NETWIB_CMP_EQ) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  netwib_er(netwib_buf_casecmp_str(NULL, "", &cmp));
+  if (cmp != NETWIB_CMP_EQ) {
+    return(NETWIBTEST_ERR_9);
+  }
+
+  return(NETWIB_ERR_OK);
+}
+
 /*-------------------------------------------------------------*/
 static netwib_err netwib_buf_close_test(void)
 {
@@ -607,6 +747,9 @@ netwib_err netwibtest_dat_buf(void)
   netwib_er(netwib_buf_wishspace_test());
 
   netwib_er(netwib_buf_cmp_test());
+  netwib_er(netwib_buf_casecmp_test());
+  netwib_er(netwib_buf_cmp_str_test());
+  netwib_er(netwib_buf_casecmp_str_test());
 
   netwib_er(netwib_buf_close_test());
 
