@@ -232,8 +232,8 @@ static netwib_err test_mem_thread_f(netwib_ptr infosin,
   netwib_er(netwibtest_buf_content3(&pst->bufwr, "'hello1hello2'"));
   netwib_er(netwib_thread_rwlock_rdunlock(pst->plockwr));
 
+  pinfosout = pinfosout; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pinfosout = pinfosout;
 }
 static netwib_err netwib_io_init_mem_lock_test(void)
 {
@@ -449,8 +449,8 @@ static netwib_err test_tlv_thread_f(netwib_ptr infosin,
   netwib_er(netwib_thread_rwlock_rdunlock(pst->plockwr));
   netwib_er(netwib_buf_close(&tlvbuf));
 
+  pinfosout = pinfosout; /* for compiler warning */
   return(NETWIB_ERR_OK);
-  pinfosout = pinfosout;
 }
 static netwib_err netwib_io_init_tlv_lock_test(void)
 {
