@@ -249,7 +249,7 @@ netwib_err netwibtest_ip_content(netwib_constip *pip,
   netwib_er(netwib_ip_cmp(&wantedip, pip, &cmp));
   if (cmp != NETWIB_CMP_EQ) {
     netwib_er(netwib_fmt_display("We wanted %s(%{ip}) != %{ip}\n",
-                                 &wantedstring, &wantedip, pip));
+                                 wantedstring, &wantedip, pip));
     return(NETWIBTEST_ERR_7);
   }
 
